(add-hook 'gnus-exit-gnus-hook              'close-newmail-modeline)
(add-hook 'gnus-exit-gnus-hook              'gnus-delete-incoming-files)
(add-hook 'gnus-startup-hook                'gnus-delete-incoming-files)
(add-hook 'gnus-startup-hook                'init-newmail-modeline)
(add-hook 'gnus-after-getting-new-news-hook 'make-newmail-modeline)
(add-hook 'gnus-started-hook                'make-newmail-modeline)
(add-hook 'gnus-summary-exit-hook           'make-newmail-modeline)



(defun close-newmail-modeline ()
  (setq global-mode-string "[Gnus not running ...]")
  (force-mode-line-update)
)





(defun init-newmail-modeline ()
  (setq persistent-newmail-count 0)
)


(defvar watch-mailgroups-list '(("nnml:mail.fysikk"    "fysikk")
	  		        ("nnml:mail.INBOX"     "INBOX")
			        ("nnml:mail.asle"      "asle")
			        ("nnml:mail.ntnu"      "ntnu")
				("nnml:mail.hove"      "hove")
				("nnml:mail.com"       "com")
				("nnml:mail.hotmail"   "hotmail")
			        ("nnml:mail.stud"      "stud"))

"This is the list of (mail)groups watched by the function \"make-newmail-modeline\".
Every element in the list is a two element list, where the first element is the
fully qualified group name used to query gnus for the number of unread messages,
and the last is the name displayed in the modeline together with the number of new 
messages.

Example:
========
(setq watch-mailgroups-list '((\"nnml:mail.somelist\" \"list\")
			      (\"nnml:mail.private\"  \"private\")))

Will check the mailgroups \"nnml:mail.somelist\" and \"nnml:mail.privat\", and the
modeline will be displayed as: \"[list:2 private:3]\" if there are two and three 
unread messages in the two groups respectively.")

(defun make-newmail-modeline ()
  "This function scans through all the (mail)groups in the list \"watch-mailgroup-list\"
and queries gnus how many unread messages there are in each group. From this the
global emacs string \"global-mode-string\" is built up, and the number of unread 
messages is displayed on the mode line.

It is intended to be used together with a \"gnus-demon\" which fetches new mail periodically.
To work as intended it should be run as a hook:

    (add-hook 'gnus-after-getting-new-news-hook 'make-newmail-modeline)
    (add-hook 'gnus-started-hook                'make-newmail-modeline)
    (add-hook 'gnus-summary-exit-hook           'make-newmail-modeline)


It breaks the built emacs function \"display-time\" which will use \"global-mode-string\" 
to display the time.

If you have any suggestions to improvements I would be happy to hear from you: hove@phys.ntnu.no

Joakim Hove"
  (interactive)
  (setq global-mode-string "[") 
  (let ((total-new-mail 0))
    (let ((index 0))
      (while (< index (length watch-mailgroups-list))
	(let ((thegroup (nth index watch-mailgroups-list)))
	  (let ((group (nth 0 thegroup)) (group-name (nth 1 thegroup)))
	    (let* ((int-count (gnus-group-unread group)) (string-count (number-to-string int-count)))
	      (if (> int-count 0) 
		  (setq global-mode-string (concat global-mode-string  group-name ":"  string-count " "))
		)
	      (setq total-new-mail (+ total-new-mail int-count))
	      )
	    )
	  )
	(setq index (+ index 1))
	)
      )
    (if (equal total-new-mail 0) (setq global-mode-string "[No new mail]")
      (progn
	(setq global-mode-string (substring global-mode-string 0 -1))
	(setq global-mode-string (concat global-mode-string "]")))
      )
    (if (> total-new-mail persistent-newmail-count) (ding))
    (setq persistent-newmail-count total-new-mail)
  )
  (force-mode-line-update)
)


(provide 'gnus-modeline)
